@@ -29,12 +29,14 @@ class SKLearnTrainerSpec(ComponentSpec):
 
     PARAMETERS = {
         'model_pickle': ExecutionParameter(type=(bytes, Text)),
-        'supervised': ExecutionParameter(type=bool),
+        'label_name': ExecutionParameter(type=(str, Text)),  # If None: unsupervised
     }
     INPUTS = {
         'examples': ChannelParameter(type=standard_artifacts.Examples),
+        'schema': ChannelParameter(type=standard_artifacts.Schema),
     }
     OUTPUTS = {
+        'transformed_examples': ChannelParameter(type=standard_artifacts.Examples),
         'model': ChannelParameter(type=stfxe_artifacts.SKLearnModel),
     }
 
@@ -43,9 +45,9 @@ class SKLearnTransformSpec(ComponentSpec):
     """Salure_tfx_extensions SKLearnTransform spec"""
 
     PARAMETERS = {
-        'module_file': ExecutionParameter(type=(str, Text), optional=True),
-        'preprocessor_pipeline_name': ExecutionParameter(type=(str, Text), optional=True),
-        'preprocessor_pickle': ExecutionParameter(type=(str, Text), optional=True)
+        # 'module_file': ExecutionParameter(type=(str, Text), optional=True),
+        # 'preprocessor_pipeline_name': ExecutionParameter(type=(str, Text), optional=True),
+        'preprocessor_pickle': ExecutionParameter(type=(str, Text))
         # 'data_format': ExecutionParameter(type=(str, Text), optional=True),  # Default will be pandas
     }
     INPUTS = {
